@@ -79,8 +79,8 @@ except ImportError as error1:
 
 __Conventions__  = 'CF-1.7'
 __author__       = 'David Hassell'
-__date__         = '2019-11-08'
-__version__      = '3.0.4'
+__date__         = 'Not yet released'
+__version__      = '3.0.5'
 __cf_version__   = cfdm.core.__cf_version__
 
 from distutils.version import LooseVersion
@@ -155,12 +155,19 @@ if LooseVersion(numpy.__version__) < LooseVersion(_minimum_vn):
             _minimum_vn, numpy.__version__, numpy.__file__))
 
 # Check the version of cfunits
-_minimum_vn = '3.1.1'
+_minimum_vn = '3.2.2'
 if LooseVersion(cfunits.__version__) < LooseVersion(_minimum_vn):
     raise ValueError(
         "Bad cfunits version: cf requires cfunits version {} or later. Got {} at {}".format(
             _minimum_vn, cfunits.__version__, cfunits.__file__))
 
+# Check the version of cfdm
+_minimum_vn = '1.7.10'
+if LooseVersion(cfdm.__version__) < LooseVersion(_minimum_vn):
+    raise ValueError(
+        "Bad cfdm version: cf requires cfdm version {} or later. Got {} at {}".format(
+            _minimum_vn, cfdm.__version__, cfdm.__file__))
+
 from .constructs import Constructs
 
 from .abstract             import Coordinate
@@ -207,6 +214,7 @@ from .query                import (Query, lt, le, gt, ge, eq, ne, contain, conta
 from .constants            import *
 from .functions            import *
 from .maths                import relative_vorticity, histogram
+from .examplefield         import example_field
 
 
 from .read_write import (read,
