@@ -96,6 +96,7 @@ class DataTest(unittest.TestCase):
 ##                          'test_Data_range_mid_range',
 ##                          'test_Data_median',
 ##                          'test_Data_mean_of_upper_decile',
+#                          'test_Data__init__mask',
 #        ]
         
 #        self.test_only = ['test_Data_mean_mean_absolute_value']
@@ -108,8 +109,8 @@ class DataTest(unittest.TestCase):
 #        self.test_only = ['test_Data__collapse_WEIGHTED_MASKED']
 #        self.test_only = ['test_Data_ERROR']
 #        self.test_only = ['test_Data_sample_size']
+#        self.test_only = ['test_Data__init__mask']
 #        self.test_only = ['test_Data_section']
-#        self.test_only = ['test_Data_sd_var']
 #        self.test_only = ['test_Data_sum_of_weights_sum_of_weights2']
 #        self.test_only = ['test_Data_max_min_sum_sum_of_squares']
 #        self.test_only = ['test_Data___setitem__']
@@ -119,6 +120,35 @@ class DataTest(unittest.TestCase):
 #        self.test_only = ['test_Data_clip']
 
 
+    def test_Data__init__mask(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        for m in (1, 20, True):
+            d = cf.Data([[1,2,3], [4,5,6]], mask=m)
+            self.assertTrue(not d.count())
+            self.assertTrue(d.shape == (2, 3))
+        
+        for m in (0, False):
+            d = cf.Data([[1,2,3], [4,5,6]], mask=m)
+            self.assertTrue(d.count() == d.size)
+            self.assertTrue(d.shape == (2, 3))
+            
+        
+        d = cf.Data([[1,2,3], [4,5,6]], mask=[[0], [1]])
+        self.assertTrue(d.count() == 3)
+        self.assertTrue(d.shape == (2, 3))
+            
+        d = cf.Data([[1,2,3], [4,5,6]], mask=[0, 1, 1])
+        self.assertTrue(d.count() == 2)
+        self.assertTrue(d.shape == (2, 3))
+            
+        
+        d = cf.Data([[1,2,3], [4,5,6]], mask=[[0, 1, 0], [1, 0, 1]])
+        self.assertTrue(d.count() == 3)
+        self.assertTrue(d.shape == (2, 3))
+            
+        
     def test_Data_digitize(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
